@@ -33,6 +33,9 @@ def get_swagger_ui_html(
 
             This is normally done automatically by FastAPI using the default URL
             `/openapi.json`.
+
+            Read more about it in the
+            [FastAPI docs for Conditional OpenAPI](https://fastapi.tiangolo.com/how-to/conditional-openapi/#conditional-openapi-from-settings-and-env-vars)
             """
         ),
     ],
@@ -41,6 +44,9 @@ def get_swagger_ui_html(
         Doc(
             """
             The HTML `<title>` content, normally shown in the browser tab.
+
+            Read more about it in the
+            [FastAPI docs for Custom Docs UI Static Assets](https://fastapi.tiangolo.com/how-to/custom-docs-ui-assets/)
             """
         ),
     ],
@@ -51,6 +57,9 @@ def get_swagger_ui_html(
             The URL to use to load the Swagger UI JavaScript.
 
             It is normally set to a CDN URL.
+
+            Read more about it in the
+            [FastAPI docs for Custom Docs UI Static Assets](https://fastapi.tiangolo.com/how-to/custom-docs-ui-assets/)
             """
         ),
     ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5/swagger-ui-bundle.js",
@@ -61,6 +70,9 @@ def get_swagger_ui_html(
             The URL to use to load the Swagger UI CSS.
 
             It is normally set to a CDN URL.
+
+            Read more about it in the
+            [FastAPI docs for Custom Docs UI Static Assets](https://fastapi.tiangolo.com/how-to/custom-docs-ui-assets/)
             """
         ),
     ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5/swagger-ui.css",
@@ -77,6 +89,9 @@ def get_swagger_ui_html(
         Doc(
             """
             The OAuth2 redirect URL, it is normally automatically handled by FastAPI.
+
+            Read more about it in the
+            [FastAPI docs for Custom Docs UI Static Assets](https://fastapi.tiangolo.com/how-to/custom-docs-ui-assets/)
             """
         ),
     ] = None,
@@ -85,6 +100,9 @@ def get_swagger_ui_html(
         Doc(
             """
             A dictionary with Swagger UI OAuth2 initialization configurations.
+
+            Read more about the available configuration options in the
+            [Swagger UI docs](https://swagger.io/docs/open-source-tools/swagger-ui/usage/oauth2/).
             """
         ),
     ] = None,
@@ -95,6 +113,9 @@ def get_swagger_ui_html(
             Configuration parameters for Swagger UI.
 
             It defaults to [swagger_ui_default_parameters][fastapi.openapi.docs.swagger_ui_default_parameters].
+
+            Read more about it in the
+            [FastAPI docs about how to Configure Swagger UI](https://fastapi.tiangolo.com/how-to/configure-swagger-ui/).
             """
         ),
     ] = None,
@@ -118,6 +139,7 @@ def get_swagger_ui_html(
     <!DOCTYPE html>
     <html>
     <head>
+    <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <link type="text/css" rel="stylesheet" href="{swagger_css_url}">
     <link rel="shortcut icon" href="{swagger_favicon_url}">
     <title>{title}</title>
@@ -168,6 +190,9 @@ def get_redoc_html(
 
             This is normally done automatically by FastAPI using the default URL
             `/openapi.json`.
+
+            Read more about it in the
+            [FastAPI docs for Conditional OpenAPI](https://fastapi.tiangolo.com/how-to/conditional-openapi/#conditional-openapi-from-settings-and-env-vars)
             """
         ),
     ],
@@ -176,6 +201,9 @@ def get_redoc_html(
         Doc(
             """
             The HTML `<title>` content, normally shown in the browser tab.
+
+            Read more about it in the
+            [FastAPI docs for Custom Docs UI Static Assets](https://fastapi.tiangolo.com/how-to/custom-docs-ui-assets/)
             """
         ),
     ],
@@ -186,6 +214,9 @@ def get_redoc_html(
             The URL to use to load the ReDoc JavaScript.
 
             It is normally set to a CDN URL.
+
+            Read more about it in the
+            [FastAPI docs for Custom Docs UI Static Assets](https://fastapi.tiangolo.com/how-to/custom-docs-ui-assets/)
             """
         ),
     ] = "https://cdn.jsdelivr.net/npm/redoc@2/bundles/redoc.standalone.js",
